""""""

class InvalidPaymentType(Exception):
    pass


class InvalidPhoneNumber(Exception):
    pass


class InvalidAmountType(Exception):
    pass


class InvalidCurrencyType(Exception):
    pass


class MissingToken(Exception):
    pass
